@@ -3,7 +3,7 @@ BEGIN {
   $Email::Simple::Markdown::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Email::Simple::Markdown::VERSION = '0.4.0';
+  $Email::Simple::Markdown::VERSION = '0.5.0';
 }
 # ABSTRACT: simple email creation with auto text and html multipart body
 
@@ -25,18 +25,17 @@ use parent 'Email::Simple';
 sub create {
     my ( $self, %arg ) = @_;
 
-    my @local_args = qw/ css markdown_engine pre_markdown_filter /;
+    my @local_args = qw/ css markdown_engine pre_markdown_filter charset /;
     my %md_arg;
     @md_arg{@local_args} = delete @arg{@local_args};
 
-    my $css = delete $arg{css};
-
     my $email = $self->SUPER::create(%arg);
 
     $email->markdown_engine_set(
         $md_arg{markdown_engine}||'auto'
     );
 
+    $self->charset_set( $md_arg{charset} ) if $md_arg{charset};
     $email->css_set($md_arg{css}) if $md_arg{css};
     $email->pre_markdown_filter_set($md_arg{pre_markdown_filter}) 
         if $md_arg{pre_markdown_filter};
@@ -96,13 +95,23 @@ sub css_set {
     }
 
     $self->{markdown_css} = $css;
+
+    return $self;
 }
 
 
 sub pre_markdown_filter_set {
     my ( $self, $sub ) = @_;
     $self->{markdown_filter} = $sub;
-    return;
+    return $self;
+}
+
+
+sub charset_set {
+    my( $self, $charset ) = @_;
+    $self->{markdown_charset} = $charset;
+
+    return $self;
 }
 
 
@@ -134,12 +143,16 @@ sub with_markdown {
 
     $mail->parts_set([
         Email::MIME->create(
-            attributes => { content_type => 'text/plain' },
+            attributes => { 
+                content_type => 'text/plain', 
+                charset => $self->{markdown_charset} 
+            },
             body => $body,
         ),
         Email::MIME->create(
             attributes => {
                 content_type => 'text/html',
+                charset => $self->{markdown_charset},
                 encoding => 'quoted-printable',
             },
             body => $markdown,
@@ -164,7 +177,7 @@ Email::Simple::Markdown - simple email creation with auto text and html multipar
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 SYNOPSIS
 
@@ -216,6 +229,11 @@ stylesheet, wrapped by a I<css> tag.
 
 See C<pre_markdown_filter_set>.
 
+=item charset => $charset
+
+The character set supplied to C<Email::MIME::create()>. By default, no character set 
+is passed.
+
 =back
 
 =head2 markdown_engine
@@ -265,6 +283,10 @@ E.g., to add a header to the email:
         s#^#<div id="header">My Corp <img src='..' /></div>#;
     });
 
+=head2 charset_set( $charset )
+
+Sets the charset to be used by the email.
+
 =head2 with_markdown()
 
 Returns an L<Email::Abstract> representation of the email, with 
